Enum Event

#[non_exhaustive]
pub enum Event { Enter { output: WlOutput, }, Leave { output: WlOutput, }, PreferredBufferScale { factor: i32, }, PreferredBufferTransform { transform: WEnum<Transform>, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Enter

surface enters an output

This is emitted whenever a surface’s creation, movement, or resizing results in some part of it being within the scanout region of an output.

Note that a surface may be overlapping with zero or more outputs.

Fields

output: WlOutput

output entered by the surface



Leave

surface leaves an output

This is emitted whenever a surface’s creation, movement, or resizing results in it no longer having any part of it within the scanout region of an output.

Clients should not use the number of outputs the surface is on for frame throttling purposes. The surface might be hidden even if no leave event has been sent, and the compositor might expect new surface content updates even if no enter event has been sent. The frame event should be used instead.

Fields

output: WlOutput

output left by the surface



PreferredBufferScale

preferred buffer scale for the surface

This event indicates the preferred buffer scale for this surface. It is sent whenever the compositor’s preference changes.

Before receiving this event the preferred buffer scale for this surface is 1.

It is intended that scaling aware clients use this event to scale their content and use wl_surface.set_buffer_scale to indicate the scale they have rendered with. This allows clients to supply a higher detail buffer.

The compositor shall emit a scale value greater than 0.

Only available since version 6 of the interface

Fields

factor: i32

preferred scaling factor



PreferredBufferTransform

preferred buffer transform for the surface

This event indicates the preferred buffer transform for this surface. It is sent whenever the compositor’s preference changes.

Before receiving this event the preferred buffer transform for this surface is normal.

Applying this transformation to the surface buffer contents and using wl_surface.set_buffer_transform might allow the compositor to use the surface buffer more efficiently.

Only available since version 6 of the interface

Fields

transform: WEnum<Transform>

preferred transform

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message